@@ -24,7 +24,7 @@ class BaseOptimizer(ABC):
     def __init__(self, library, device='GPU', override_params=None):
         self.library = library
 
-        self.training_params, self.int_params = self._get_params(self.library, device)
+        self.training_params, self.int_params = self._get_params(device)
         self.training_params = self._update_params(self.training_params, override_params)
 
     def _update_params(self, hyperopt_params, params):
